@@ -8,12 +8,13 @@ use Class::AutoAccess;
 use base qw(Class::AutoAccess);
 
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 BEGIN {
 	our $class_def	= {
 							element			=> 'SPAN',
 							name				=> '',
+							id					=> '',
 							has_end_tag	=> 1,
 							tabindex		=> '',
 							onafterupdate	=> '', onblur	=> '', onchange	=> '', onclick	=> '',
@@ -23,7 +24,7 @@ BEGIN {
 							onmouseout	=> '', onmouseover	=> '', onmouseup	=> '', 
 							onresize	=> '',
 							style => '', class => '',
-							attributes	=> ['name','tabindex','onafterupdate', 'onblur',
+							attributes	=> ['name','id','tabindex','onafterupdate', 'onblur',
 								'onchange', 'onclick', 'ondblclick', 'onerrorupdate',
 								'onfilterchange', 'onfocus', 'onhelp', 'onkeydown', 
 								'onkeypress', 'onkeyup', 'onmousedown', 'onmousemove',
